==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_GridCellChoiceEditor.h <==
//----------------------------------------------------------------------------
// wxGridCellChoiceEditor
// extracted from gridedit.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_GRIDCELLCHOICEEDITOR_H__
#define __CLASS_WX_GRIDCELLCHOICEEDITOR_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxGridCellChoiceEditor
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_GridCellChoiceEditor);

//----------------------------------------------------------------------------
// Object declaration for wxGridCellChoiceEditor
//----------------------------------------------------------------------------
class Object_wx_GridCellChoiceEditor : public Object_wx_GridCellEditor {
public:
	Gura_DeclareObjectAccessor(wx_GridCellChoiceEditor)
public:
	inline Object_wx_GridCellChoiceEditor(wxGridCellChoiceEditor *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_GridCellEditor(Gura_UserClass(wx_GridCellChoiceEditor), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_GridCellChoiceEditor(Class *pClass, wxGridCellChoiceEditor *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_GridCellEditor(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_GridCellChoiceEditor();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxGridCellChoiceEditor *GetEntity() {
		return dynamic_cast<wxGridCellChoiceEditor *>(_pEntity);
	}
	inline wxGridCellChoiceEditor *ReleaseEntity() {
		wxGridCellChoiceEditor *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxGridCellChoiceEditor");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_GridCellChoiceEditor.h <==
//----------------------------------------------------------------------------
// wxGridCellChoiceEditor
// extracted from gridedit.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_GRIDCELLCHOICEEDITOR_H__
#define __CLASS_WX_GRIDCELLCHOICEEDITOR_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxGridCellChoiceEditor
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_GridCellChoiceEditor);

//----------------------------------------------------------------------------
// Object declaration for wxGridCellChoiceEditor
//----------------------------------------------------------------------------
class Object_wx_GridCellChoiceEditor : public Object_wx_GridCellEditor {
public:
	Gura_DeclareObjectAccessor(wx_GridCellChoiceEditor)
public:
	inline Object_wx_GridCellChoiceEditor(wxGridCellChoiceEditor *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_GridCellEditor(Gura_UserClass(wx_GridCellChoiceEditor), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_GridCellChoiceEditor(Class *pClass, wxGridCellChoiceEditor *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_GridCellEditor(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_GridCellChoiceEditor();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxGridCellChoiceEditor *GetEntity() {
		return dynamic_cast<wxGridCellChoiceEditor *>(_pEntity);
	}
	inline wxGridCellChoiceEditor *ReleaseEntity() {
		wxGridCellChoiceEditor *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxGridCellChoiceEditor");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
